======================
Command Line Interface
======================
bohicalog automatically installs the command :code:`bohicalog`. See
:code:`bohicalog --help` for usage details.

.. click:: bohicalog.cli:main
   :prog: bohicalog
   :nested: full
